@@ -79,6 +79,7 @@ class NVD3Chart:
         * ``container`` - Place for graph
         * ``containerheader`` - Header for javascript code
         * ``jschart`` - Javascript code as string
+        * ``date_flag`` - x-axis contain date format or not
         * ``custom_tooltip_flag`` - False / True
         * ``charttooltip`` - Custom tooltip string
         * ``header_css`` - False / True
@@ -103,7 +104,9 @@ class NVD3Chart:
     containerheader = ''
     jschart = None
     custom_tooltip_flag = False
-    charttooltip = None
+    date_flag = False
+    charttooltip = ''
+    tooltip_condition_string = ''
 
     header_css = ['http://nvd3.org/src/nv.d3.css']
     header_js = ['http://nvd3.org/lib/d3.v2.js', 'http://nvd3.org/nv.d3.js']
@@ -131,7 +134,7 @@ class NVD3Chart:
         if 'resize' in kwargs and kwargs["resize"]:
             self.resize = True
 
-    def add_serie(self, y, x, name=None, **kwargs):
+    def add_serie(self, y, x, name=None, extra={}, **kwargs):
         """
         add serie - Series are list of data that will be plotted
         y {1, 2, 3, 4, 5} / x {1, 2, 3, 4, 5}
@@ -143,6 +146,7 @@ class NVD3Chart:
             x = [str(d) for d in x]
 
         x = sorted(x)
+        # For scatterChart shape & size fields are added in serie
         if 'shape' in kwargs:
             serie = [{"x": x[i], "y": y, "shape": kwargs["shape"], "size": random.randint(1, 3)} for i, y in enumerate(y)]
         else:
@@ -168,6 +172,38 @@ class NVD3Chart:
         if 'disabled' in kwargs and kwargs["disabled"]:
             data_keyvalue["disabled"] = 'true'
 
+        if extra.get('tooltip'):
+            self.custom_tooltip_flag = True
+
+            if self.model != 'pieChart':
+                _start = extra['tooltip']['y_start']
+                _end = extra['tooltip']['y_end']
+                _start = ("'" + str(_start) + "' + ") if _start else ''
+                _end = (" + '" + str(_end) + "'") if _end else ''
+
+                if self.model == 'linePlusBarChart':
+                    self.tooltip_condition_string += stab(3) + "if(key.indexOf('" + name + "') > -1 ){\n" +\
+                        stab(4) + "var y = " + _start + " String(graph.point.y) " + _end + ";\n" +\
+                        stab(3) + "}\n"
+                elif self.model == 'cumulativeLineChart':
+                    self.tooltip_condition_string += stab(3) + "if(key == '" + name + "'){\n" +\
+                        stab(4) + "var y = " + _start + " String(e) " + _end + ";\n" +\
+                        stab(3) + "}\n"
+                else:
+                    self.tooltip_condition_string += stab(3) + "if(key == '" + name + "'){\n" +\
+                        stab(4) + "var y = " + _start + " String(graph.point.y) " + _end + ";\n" +\
+                        stab(3) + "}\n"
+
+            if self.model == 'pieChart':
+                _start = extra['tooltip']['y_start']
+                _end = extra['tooltip']['y_end']
+                _start = ("'" + str(_start) + "' + ") if _start else ''
+                _end = (" + '" + str(_end) + "'") if _end else ''
+                self.tooltip_condition_string += \
+                    "var y = " + _start + " String(e.point.y) " + _end + ";\n"
+
+        #print self.tooltip_condition_string
+        #print "----------------------------"
         self.series.append(data_keyvalue)
 
     def set_graph_height(self, height):
@@ -182,8 +218,12 @@ class NVD3Chart:
         """Set containerheader"""
         self.containerheader = containerheader
 
+    def set_date_flag(self, date_flag=False):
+        """Set date falg"""
+        self.date_flag = date_flag
+
     def set_custom_tooltip_flag(self, custom_tooltip_flag):
-        """Set custom_tooltip_flag"""
+        """Set custom_tooltip_flag & date_flag"""
         self.custom_tooltip_flag = custom_tooltip_flag
 
     def __str__(self):
@@ -226,14 +266,41 @@ class NVD3Chart:
 
         self.container += '<div id="%s"><svg %s></svg></div>\n' % (self.name, self.style)
 
-    def buildtooltip(self):
+    def build_custom_tooltip(self):
         """generate custom tooltip for the chart"""
         if self.custom_tooltip_flag:
-            self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
-                stab(3) + "var x = d3.time.format('%s')(new Date(parseInt(graph.point.x)));\n" % self.dateformat +\
-                stab(3) + "tooltip_str = '<center><b>'+key+'</b></center>' + graph.point.y +' on ' + x ;" +\
-                stab(3) + "return tooltip_str;\n" + \
-                stab(2) + "});\n"
+            if not self.date_flag:
+                if self.model == 'pieChart':
+                    self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
+                        stab(3) + "var x = String(key);\n" +\
+                        stab(3) + self.tooltip_condition_string +\
+                        stab(3) + "tooltip_str = '<center><b>'+x+'</b></center>' + y;\n" +\
+                        stab(3) + "return tooltip_str;\n" + \
+                        stab(2) + "});\n"
+                elif self.model == 'lineChart':
+                    self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
+                        stab(3) + "var x = String(e);\n" +\
+                        stab(3) + "var y = String(graph.point.y);\n" +\
+                        self.tooltip_condition_string +\
+                        stab(3) + "tooltip_str = '<center><b>'+key+'</b></center>' + y + ' at ' + x;\n" +\
+                        stab(3) + "return tooltip_str;\n" + \
+                        stab(2) + "});\n"
+                else:
+                    self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
+                        stab(3) + "var x = String(graph.point.x);\n" +\
+                        stab(3) + "var y = String(graph.point.y);\n" +\
+                        self.tooltip_condition_string +\
+                        stab(3) + "tooltip_str = '<center><b>'+key+'</b></center>' + y + ' at ' + x;\n" +\
+                        stab(3) + "return tooltip_str;\n" + \
+                        stab(2) + "});\n"
+            else:
+                self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
+                    stab(3) + "var x = d3.time.format('%s')(new Date(parseInt(graph.point.x)));\n" % self.dateformat +\
+                    stab(3) + "var y = String(graph.point.y);\n" +\
+                    self.tooltip_condition_string +\
+                    stab(3) + "tooltip_str = '<center><b>'+key+'</b></center>' + y + ' on ' + x;\n" +\
+                    stab(3) + "return tooltip_str;\n" + \
+                    stab(2) + "});\n"
 
     def buildjschart(self):
         """generate javascript code for the chart"""
@@ -267,9 +334,12 @@ class NVD3Chart:
             datum = "[data_%s[0].values]" % self.name
 
         # add custom tooltip string in jschart
-        if self.custom_tooltip_flag:
-            self.buildtooltip()
-            self.jschart += self.charttooltip
+        # default condition (if build_custom_tooltip is not called explicitly with date_flag=True)
+        if self.tooltip_condition_string == '':
+            self.tooltip_condition_string = 'var y = String(graph.point.y);\n'
+
+        self.build_custom_tooltip()
+        self.jschart += self.charttooltip
 
         #Inject data to D3
         self.jschart += stab(2) + "d3.select('#%s svg')\n" % self.name + \
@@ -332,7 +402,7 @@ def _main():
     """
     # Parse arguments
     usage = "usage: nvd3.py [options]"
-    parser = OptionParser(usage=usage, version="python-nvd3 " + __version__ + " - Python wrapper for nvd3 ")
+    parser = OptionParser(usage=usage, version="python-nvd3 0.2.2 - Python wrapper for nvd3 ")
     parser.add_option("-q", "--quiet",
                   action="store_false", dest="verbose", default=True,
                   help="don't print messages to stdout")
